@@ -1,11 +1,21 @@
 from __future__ import annotations
-from typing import List
-from pymint.mintparams import MINTParams
+
+from typing import TYPE_CHECKING, List
+
 from parchmint.component import Component
-from pymint import MINTLayer
+
+if TYPE_CHECKING:
+    from pymint import MINTLayer
+
+from pymint.mintparams import MINTParams
 
 
 class MINTComponent(Component):
+    """Component Class abstracting parchmint component
+    while adding helper methods to generate MINT
+
+    """
+
     def __init__(
         self, name: str, technology: str, params: dict, layers: List[MINTLayer] = None
     ) -> None:
